'use strict';

const postcss = require('postcss-js');
const autoprefixer = require('autoprefixer');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }

const postcss__default = /*#__PURE__*/_interopDefaultLegacy(postcss);
const autoprefixer__default = /*#__PURE__*/_interopDefaultLegacy(autoprefixer);

const prefixer = postcss__default.sync([autoprefixer__default]);
function autoprefixerPreset() {
  return {
    name: "unocss-preset-autoprefixer",
    postprocess: (util) => {
      const entries = util.entries;
      util.entries = [
        ...entries.filter((item) => item[0].startsWith("--un")),
        ...genEntries(prefixer(Object.fromEntries(entries.filter((item) => !item[0].startsWith("--un")))))
      ];
    }
  };
}
const hyphenate = (str) => str.replace(/(?:^|\B)([A-Z])/g, "-$1").toLowerCase();
function genEntries(obj) {
  const res = [];
  Object.keys(obj).forEach((key) => {
    const values = obj[key];
    if (Array.isArray(values)) {
      values.forEach((v) => {
        res.push([hyphenate(key), v]);
      });
    } else if (typeof values === "string") {
      res.push([hyphenate(key), values]);
    }
  });
  return res;
}

module.exports = autoprefixerPreset;
